/****************************************************************************
** Meta object code from reading C++ file 'directorymergewindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdiff3-1.12.5/src/directorymergewindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'directorymergewindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20DirectoryMergeWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto DirectoryMergeWindow::qt_create_metaobjectdata<qt_meta_tag_ZN20DirectoryMergeWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DirectoryMergeWindow",
        "startDiffMerge",
        "",
        "QStringList&",
        "errors",
        "fn1",
        "fn2",
        "fn3",
        "ofn",
        "TotalDiffStatus*",
        "updateAvailabilities",
        "statusBarMessage",
        "msg",
        "reload",
        "mergeCurrentFile",
        "compareCurrentFile",
        "slotRunOperationForAllItems",
        "slotRunOperationForCurrentItem",
        "mergeResultSaved",
        "fileName",
        "slotChooseAEverywhere",
        "slotChooseBEverywhere",
        "slotChooseCEverywhere",
        "slotAutoChooseEverywhere",
        "slotNoOpEverywhere",
        "slotFoldAllSubdirs",
        "slotUnfoldAllSubdirs",
        "slotShowIdenticalFiles",
        "slotShowDifferentFiles",
        "slotShowFilesOnlyInA",
        "slotShowFilesOnlyInB",
        "slotShowFilesOnlyInC",
        "slotSynchronizeDirectories",
        "slotChooseNewerFiles",
        "slotCompareExplicitlySelectedFiles",
        "slotMergeExplicitlySelectedFiles",
        "slotCurrentDoNothing",
        "slotCurrentChooseA",
        "slotCurrentChooseB",
        "slotCurrentChooseC",
        "slotCurrentMerge",
        "slotCurrentDelete",
        "slotCurrentCopyAToB",
        "slotCurrentCopyBToA",
        "slotCurrentDeleteA",
        "slotCurrentDeleteB",
        "slotCurrentDeleteAAndB",
        "slotCurrentMergeToA",
        "slotCurrentMergeToB",
        "slotCurrentMergeToAAndB",
        "slotSaveMergeState",
        "slotLoadMergeState",
        "slotRefresh",
        "onDoubleClick",
        "QModelIndex",
        "onExpanded",
        "currentChanged",
        "current",
        "previous"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startDiffMerge'
        QtMocHelpers::SignalData<void(QStringList &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, TotalDiffStatus *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
            { QMetaType::QString, 8 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'updateAvailabilities'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusBarMessage'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mergeCurrentFile'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'compareCurrentFile'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRunOperationForAllItems'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRunOperationForCurrentItem'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mergeResultSaved'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'slotChooseAEverywhere'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseBEverywhere'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseCEverywhere'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAutoChooseEverywhere'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNoOpEverywhere'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFoldAllSubdirs'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUnfoldAllSubdirs'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowIdenticalFiles'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowDifferentFiles'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowFilesOnlyInA'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowFilesOnlyInB'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowFilesOnlyInC'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSynchronizeDirectories'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChooseNewerFiles'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCompareExplicitlySelectedFiles'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMergeExplicitlySelectedFiles'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentDoNothing'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentChooseA'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentChooseB'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentChooseC'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentMerge'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentDelete'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentCopyAToB'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentCopyBToA'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentDeleteA'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentDeleteB'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentDeleteAAndB'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentMergeToA'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentMergeToB'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentMergeToAAndB'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveMergeState'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoadMergeState'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDoubleClick'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(53, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 54, 2 },
        }}),
        // Slot 'onExpanded'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'currentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(56, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 54, 57 }, { 0x80000000 | 54, 58 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DirectoryMergeWindow, qt_meta_tag_ZN20DirectoryMergeWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DirectoryMergeWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DirectoryMergeWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DirectoryMergeWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DirectoryMergeWindowE_t>.metaTypes,
    nullptr
} };

void DirectoryMergeWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DirectoryMergeWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startDiffMerge((*reinterpret_cast<std::add_pointer_t<QStringList&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<TotalDiffStatus*>>(_a[9]))); break;
        case 1: _t->updateAvailabilities(); break;
        case 2: _t->statusBarMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->reload(); break;
        case 4: _t->mergeCurrentFile(); break;
        case 5: _t->compareCurrentFile(); break;
        case 6: _t->slotRunOperationForAllItems(); break;
        case 7: _t->slotRunOperationForCurrentItem(); break;
        case 8: _t->mergeResultSaved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->slotChooseAEverywhere(); break;
        case 10: _t->slotChooseBEverywhere(); break;
        case 11: _t->slotChooseCEverywhere(); break;
        case 12: _t->slotAutoChooseEverywhere(); break;
        case 13: _t->slotNoOpEverywhere(); break;
        case 14: _t->slotFoldAllSubdirs(); break;
        case 15: _t->slotUnfoldAllSubdirs(); break;
        case 16: _t->slotShowIdenticalFiles(); break;
        case 17: _t->slotShowDifferentFiles(); break;
        case 18: _t->slotShowFilesOnlyInA(); break;
        case 19: _t->slotShowFilesOnlyInB(); break;
        case 20: _t->slotShowFilesOnlyInC(); break;
        case 21: _t->slotSynchronizeDirectories(); break;
        case 22: _t->slotChooseNewerFiles(); break;
        case 23: _t->slotCompareExplicitlySelectedFiles(); break;
        case 24: _t->slotMergeExplicitlySelectedFiles(); break;
        case 25: _t->slotCurrentDoNothing(); break;
        case 26: _t->slotCurrentChooseA(); break;
        case 27: _t->slotCurrentChooseB(); break;
        case 28: _t->slotCurrentChooseC(); break;
        case 29: _t->slotCurrentMerge(); break;
        case 30: _t->slotCurrentDelete(); break;
        case 31: _t->slotCurrentCopyAToB(); break;
        case 32: _t->slotCurrentCopyBToA(); break;
        case 33: _t->slotCurrentDeleteA(); break;
        case 34: _t->slotCurrentDeleteB(); break;
        case 35: _t->slotCurrentDeleteAAndB(); break;
        case 36: _t->slotCurrentMergeToA(); break;
        case 37: _t->slotCurrentMergeToB(); break;
        case 38: _t->slotCurrentMergeToAAndB(); break;
        case 39: _t->slotSaveMergeState(); break;
        case 40: _t->slotLoadMergeState(); break;
        case 41: _t->slotRefresh(); break;
        case 42: _t->onDoubleClick((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 43: _t->onExpanded(); break;
        case 44: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DirectoryMergeWindow::*)(QStringList & , const QString & , const QString & , const QString & , const QString & , const QString & , const QString & , const QString & , TotalDiffStatus * )>(_a, &DirectoryMergeWindow::startDiffMerge, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirectoryMergeWindow::*)()>(_a, &DirectoryMergeWindow::updateAvailabilities, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirectoryMergeWindow::*)(const QString & )>(_a, &DirectoryMergeWindow::statusBarMessage, 2))
            return;
    }
}

const QMetaObject *DirectoryMergeWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirectoryMergeWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DirectoryMergeWindowE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int DirectoryMergeWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void DirectoryMergeWindow::startDiffMerge(QStringList & _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, const QString & _t7, const QString & _t8, TotalDiffStatus * _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}

// SIGNAL 1
void DirectoryMergeWindow::updateAvailabilities()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DirectoryMergeWindow::statusBarMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN18DirectoryMergeInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto DirectoryMergeInfo::qt_create_metaobjectdata<qt_meta_tag_ZN18DirectoryMergeInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DirectoryMergeInfo",
        "gotFocus",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gotFocus'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DirectoryMergeInfo, qt_meta_tag_ZN18DirectoryMergeInfoE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DirectoryMergeInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DirectoryMergeInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DirectoryMergeInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DirectoryMergeInfoE_t>.metaTypes,
    nullptr
} };

void DirectoryMergeInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DirectoryMergeInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gotFocus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DirectoryMergeInfo::*)()>(_a, &DirectoryMergeInfo::gotFocus, 0))
            return;
    }
}

const QMetaObject *DirectoryMergeInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirectoryMergeInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DirectoryMergeInfoE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int DirectoryMergeInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DirectoryMergeInfo::gotFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
